@@ -11,9 +11,7 @@
 #' @param max_feature_to_select up limit to the number of words that can be selected
 #'
 #' @rdname interactive_text_explanations
-#' @importFrom shiny fluidPage textAreaInput shinyApp sliderInput mainPanel titlePanel hr need validate h1 h2 h3 h4 h5 h6 numericInput selectInput sidebarPanel renderPlot plotOutput
 #' @importFrom stringi stri_count_words stri_replace_all_fixed
-#' @importFrom shinythemes shinytheme
 #' @importFrom assertthat assert_that is.string is.count
 #' @export
 #'
@@ -50,6 +48,9 @@ interactive_text_explanations <- function(explainer, window_title = "Text model
                                           minimum_lentgh = 3,
                                           minimum_lentgh_error = "Text provided is too short to be explained (>= 3).",
                                           max_feature_to_select = 20) {
+  if (!requireNamespace('shiny', quietly = TRUE) || !requireNamespace('shinythemes', quietly = TRUE)) {
+    stop('shiny and shinythemes are required for this functionality', call. = FALSE)
+  }
   assert_that(is.list(explainer))
   assert_that(is.string(window_title))
   assert_that(is.string(title))
@@ -66,17 +67,17 @@ interactive_text_explanations <- function(explainer, window_title = "Text model
     as.list(strategies)
   })
 
-  ui <- fluidPage(title = window_title,
-                  theme = shinytheme("superhero"),
-                  titlePanel(title = title),
-                  hr(),
-                  sidebarPanel(
-                    textAreaInput("text_to_explain", label = NULL, resize = "both", placeholder = place_holder, height = "200px"),
-                    numericInput("number_permutations", label = h5("Quantity of permutations to generate"), value = 5000, step = 1000),
-                    selectInput("feature_selection_strategy", label = h5("Word selection strategies"), choices = feature_selection_strategy, selected = "auto"),
-                    sliderInput("number_features_to_explain", label = h5("Number of words to select"), min = 1, max = max_feature_to_select, value = 2, ticks = FALSE)
+  ui <- shiny::fluidPage(title = window_title,
+                  theme = shinythemes::shinytheme("superhero"),
+                  shiny::titlePanel(title = title),
+                  shiny::hr(),
+                  shiny::sidebarPanel(
+                    shiny::textAreaInput("text_to_explain", label = NULL, resize = "both", placeholder = place_holder, height = "200px"),
+                    shiny::numericInput("number_permutations", label = shiny::h5("Quantity of permutations to generate"), value = 5000, step = 1000),
+                    shiny::selectInput("feature_selection_strategy", label = shiny::h5("Word selection strategies"), choices = feature_selection_strategy, selected = "auto"),
+                    shiny::sliderInput("number_features_to_explain", label = shiny::h5("Number of words to select"), min = 1, max = max_feature_to_select, value = 2, ticks = FALSE)
                   ),
-                  mainPanel(
+                  shiny::mainPanel(
                     text_explanations_output("text_explanations_plot")#,
                     #plotOutput("feature_weight_plot")
                   ))
@@ -84,8 +85,8 @@ interactive_text_explanations <- function(explainer, window_title = "Text model
   # Define server logic for slider examples ----
   server <- function(input, output) {
     output$text_explanations_plot <- render_text_explanations({
-      validate(
-        need(stri_count_words(input$text_to_explain) >= minimum_lentgh, message = minimum_lentgh_error)
+      shiny::validate(
+        shiny::need(stri_count_words(input$text_to_explain) >= minimum_lentgh, message = minimum_lentgh_error)
       )
       shared_states$explanations <<- explain(input$text_to_explain, explainer, n_labels = 1, n_features = input$number_features_to_explain, feature_select = input$feature_selection_strategy, n_permutations = input$number_permutations)
       plot_text_explanations(shared_states$explanations)
@@ -97,7 +98,7 @@ interactive_text_explanations <- function(explainer, window_title = "Text model
     #   plot_features(shared_states$explanations)
     # })
   }
-  shinyApp(ui, server)
+  shiny::shinyApp(ui, server)
 }
 
 #' Shiny widget output
@@ -106,11 +107,13 @@ interactive_text_explanations <- function(explainer, window_title = "Text model
 #' @param outputId output variable to read from
 #' @param width,height Must be a valid CSS unit or a number, which will be coerced to a string and have "px" appended.
 #' @return An output function that enables the use of the widget within Shiny applications.
-#' @importFrom htmlwidgets shinyWidgetOutput
 #' @rdname interactive_text_explanations
 #' @export
 text_explanations_output <- function(outputId, width = "100%", height = "400px") {
-  shinyWidgetOutput(outputId, "plot_text_explanations", width, height, package = "lime")
+  if (!requireNamespace('htmlwidgets', quietly = TRUE)) {
+    stop('htmlwidgets is required for this functionality', call. = FALSE)
+  }
+  htmlwidgets::shinyWidgetOutput(outputId, "plot_text_explanations", width, height, package = "lime")
 }
 
 #' Shiny widget render
@@ -121,11 +124,13 @@ text_explanations_output <- function(outputId, width = "100%", height = "400px")
 #' @param quoted Is `expr` a quoted expression (with [quote()])? This
 #'   is useful if you want to save an expression in a variable.
 #' @return A render function that enables the use of the widget within Shiny applications.
-#' @importFrom htmlwidgets shinyRenderWidget
 #' @rdname interactive_text_explanations
 #' @export
 render_text_explanations <- function(expr, env = parent.frame(), quoted = FALSE) {
+  if (!requireNamespace('htmlwidgets', quietly = TRUE)) {
+    stop('htmlwidgets is required for this functionality', call. = FALSE)
+  }
   if (!quoted) { expr <- substitute(expr) } # force quoted
-  shinyRenderWidget(expr, text_explanations_output, env, quoted = TRUE)
+  htmlwidgets::shinyRenderWidget(expr, text_explanations_output, env, quoted = TRUE)
 }
 
